@@ -37,7 +37,6 @@
 
 #include "gs-dbus-helper.h"
 #include "gs-box.h"
-#include "gs-cleanup.h"
 #include "gs-first-run-dialog.h"
 #include "gs-shell.h"
 #include "gs-update-monitor.h"
@@ -67,10 +66,6 @@ struct _GsApplication {
 	GSettings       *settings;
 };
 
-struct _GsApplicationClass {
-	GtkApplicationClass parent_class;
-};
-
 G_DEFINE_TYPE (GsApplication, gs_application, GTK_TYPE_APPLICATION);
 
 gboolean
@@ -90,6 +85,28 @@ gs_application_has_active_window (GsApplication *application)
 static void
 gs_application_init (GsApplication *application)
 {
+	const GOptionEntry options[] = {
+		{ "mode", '\0', 0, G_OPTION_ARG_STRING, NULL,
+		  /* TRANSLATORS: this is a command line option */
+		  _("Start up mode: either ‘updates’, ‘updated’, ‘installed’ or ‘overview’"), _("MODE") },
+		{ "search", '\0', 0, G_OPTION_ARG_STRING, NULL,
+		  _("Search for applications"), _("SEARCH") },
+		{ "details", '\0', 0, G_OPTION_ARG_STRING, NULL,
+		  _("Show application details"), _("ID") },
+		{ "local-filename", '\0', 0, G_OPTION_ARG_FILENAME, NULL,
+		  _("Open a local package file"), _("FILENAME") },
+		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, NULL,
+		  _("Show verbose debugging information"), NULL },
+		{ "profile", 0, 0, G_OPTION_ARG_NONE, NULL,
+		  _("Show profiling information for the service"), NULL },
+		{ "prefer-local", '\0', 0, G_OPTION_ARG_NONE, NULL,
+		  _("Prefer local file sources to AppStream"), NULL },
+		{ "version", 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL },
+		{ NULL }
+	};
+
+	g_application_add_main_option_entries (G_APPLICATION (application), options);
+
 	application->profile = gs_profile_new ();
 }
 
@@ -164,7 +181,7 @@ static void
 gs_application_initialize_plugins (GsApplication *app)
 {
 	static gboolean initialized = FALSE;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	if (initialized)
 		return;
@@ -183,13 +200,33 @@ gs_application_initialize_plugins (GsApplication *app)
 
 }
 
-static void
-gs_application_provide_search (GsApplication *app)
+static gboolean
+gs_application_dbus_register (GApplication    *application,
+                              GDBusConnection *connection,
+                              const gchar     *object_path,
+                              GError         **error)
 {
+	GsApplication *app = GS_APPLICATION (application);
+
 	gs_application_initialize_plugins (app);
 	app->search_provider = gs_shell_search_provider_new ();
 	gs_shell_search_provider_setup (app->search_provider,
 					app->plugin_loader);
+
+	return gs_shell_search_provider_register (app->search_provider, connection, error);
+}
+
+static void
+gs_application_dbus_unregister (GApplication    *application,
+                                GDBusConnection *connection,
+                                const gchar     *object_path)
+{
+	GsApplication *app = GS_APPLICATION (application);
+
+	if (app->search_provider != NULL) {
+		gs_shell_search_provider_unregister (app->search_provider);
+		g_clear_object (&app->search_provider);
+	}
 }
 
 static void
@@ -209,8 +246,8 @@ gs_application_show_first_run_dialog (GsApplication *app)
 static void
 theme_changed (GtkSettings *settings, GParamSpec *pspec, GsApplication *app)
 {
-	_cleanup_object_unref_ GFile *file = NULL;
-	_cleanup_free_ gchar *theme = NULL;
+	g_autoptr(GFile) file = NULL;
+	g_autofree gchar *theme = NULL;
 
 	g_object_get (settings, "gtk-theme-name", &theme, NULL);
 	if (g_strcmp0 (theme, "HighContrast") == 0) {
@@ -328,7 +365,7 @@ profile_activated (GSimpleAction *action,
 static void
 offline_updates_cancel (void)
 {
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 	if (!pk_offline_cancel (NULL, &error))
 		g_warning ("failed to cancel the offline update: %s", error->message);
 }
@@ -341,7 +378,7 @@ offline_update_cb (GsPluginLoader *plugin_loader,
 		   GAsyncResult *res,
 		   GsApplication *app)
 {
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 	if (!gs_plugin_loader_offline_update_finish (plugin_loader, res, &error)) {
 		g_warning ("Failed to trigger offline update: %s", error->message);
 		return;
@@ -465,9 +502,9 @@ launch_activated (GSimpleAction *action,
 {
 	const gchar *desktop_id;
 	GdkDisplay *display;
-	_cleanup_error_free_ GError *error = NULL;
-	_cleanup_object_unref_ GAppInfo *appinfo = NULL;
-	_cleanup_object_unref_ GAppLaunchContext *context = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GAppInfo) appinfo = NULL;
+	g_autoptr(GAppLaunchContext) context = NULL;
 
 	desktop_id = g_variant_get_string (parameter, NULL);
 	display = gdk_display_get_default ();
@@ -558,7 +595,6 @@ gs_application_startup (GApplication *application)
 	GS_APPLICATION (application)->settings = g_settings_new ("org.gnome.software");
 	gs_application_monitor_permission (GS_APPLICATION (application));
 	gs_application_monitor_updates (GS_APPLICATION (application));
-	gs_application_provide_search (GS_APPLICATION (application));
 	gs_application_monitor_network (GS_APPLICATION (application));
 	gs_folders_convert ();
 }
@@ -588,7 +624,6 @@ gs_application_dispose (GObject *object)
 	g_clear_object (&app->update_monitor);
 	g_clear_object (&app->proxy_settings);
 	g_clear_object (&app->profile);
-	g_clear_object (&app->search_provider);
 	g_clear_object (&app->network_monitor);
 	g_clear_object (&app->dbus_helper);
 	g_clear_object (&app->settings);
@@ -596,113 +631,62 @@ gs_application_dispose (GObject *object)
 	G_OBJECT_CLASS (gs_application_parent_class)->dispose (object);
 }
 
-static gboolean
-gs_application_local_command_line (GApplication *app, gchar ***args, gint *status)
+static int
+gs_application_handle_local_options (GApplication *app, GVariantDict *options)
 {
-	GOptionContext *context;
-	gboolean gapplication_service = FALSE;
-	gchar *mode = NULL;
-	gchar *search = NULL;
-	gchar *id = NULL;
-	gboolean activate_ui = TRUE;
-	gboolean prefer_local = FALSE;
-	gboolean version = FALSE;
-	gboolean profile = FALSE;
-	gboolean verbose = FALSE;
-	gint argc;
-	_cleanup_free_ gchar *local_filename = NULL;
-	const GOptionEntry options[] = {
-		{ "gapplication-service", '\0', 0, G_OPTION_ARG_NONE, &gapplication_service,
-		   _("Enter GApplication service mode"), NULL }, 
-		{ "mode", '\0', 0, G_OPTION_ARG_STRING, &mode,
-		  /* TRANSLATORS: this is a command line option */
-		  _("Start up mode: either ‘updates’, ‘updated’, ‘installed’ or ‘overview’"), _("MODE") },
-		{ "search", '\0', 0, G_OPTION_ARG_STRING, &search,
-		  _("Search for applications"), _("SEARCH") },
-		{ "details", '\0', 0, G_OPTION_ARG_STRING, &id,
-		  _("Show application details"), _("ID") },
-		{ "local-filename", '\0', 0, G_OPTION_ARG_FILENAME, &local_filename,
-		  _("Open a local package file"), _("FILENAME") },
-		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
-		  _("Show verbose debugging information"), NULL },
-		{ "profile", 0, 0, G_OPTION_ARG_NONE, &profile,
-		  _("Show profiling information for the service"), NULL },
-		{ "prefer-local", '\0', 0, G_OPTION_ARG_NONE, &prefer_local,
-		  _("Prefer local file sources to AppStream"), NULL },
-		{ "version", 0, 0, G_OPTION_ARG_NONE, &version, NULL, NULL },
-		{ NULL}
-	};
-	_cleanup_error_free_ GError *error = NULL;
+	const gchar *id;
+	const gchar *local_filename;
+	const gchar *mode;
+	const gchar *search;
+	g_autoptr(GError) error = NULL;
 
-	context = g_option_context_new ("");
-	g_option_context_add_main_entries (context, options, NULL);
-
-	argc = g_strv_length (*args);
-	if (!g_option_context_parse (context, &argc, args, &error)) {
-		g_printerr ("%s\n", error->message);
-		*status = 1;
-		goto out;
-	}
-
-	if (verbose)
+	if (g_variant_dict_contains (options, "verbose"))
 		g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
 	/* prefer local sources */
-	if (prefer_local)
+	if (g_variant_dict_contains (options, "prefer-local"))
 		g_setenv ("GNOME_SOFTWARE_PREFER_LOCAL", "true", TRUE);
 
-	if (version) {
+	if (g_variant_dict_contains (options, "version")) {
 		g_print ("gnome-software " VERSION "\n");
-		*status = 0;
-		goto out;
-	}
-
-	if (gapplication_service) {
-		GApplicationFlags flags;
-
-		flags = g_application_get_flags (app);
-		g_application_set_flags (app, flags | G_APPLICATION_IS_SERVICE);
-		activate_ui = FALSE;
+		return 0;
 	}
 
 	if (!g_application_register (app, NULL, &error)) {
 		g_printerr ("%s\n", error->message);
-		*status = 1;
-		goto out;
+		return 1;
 	}
 
-	if (profile) {
-		activate_ui = FALSE;
+	if (g_variant_dict_contains (options, "profile")) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
 						"profile",
 						NULL);
+		return 0;
 	}
 
-	if (mode != NULL) {
+	if (g_variant_dict_lookup (options, "mode", "&s", &mode)) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
 						"set-mode",
 						g_variant_new_string (mode));
-	} else if (search != NULL) {
+		return 0;
+	} else if (g_variant_dict_lookup (options, "search", "&s", &search)) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
 						"search",
 						g_variant_new_string (search));
-	} else if (id != NULL) {
+		return 0;
+	} else if (g_variant_dict_lookup (options, "details", "&s", &id)) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
 						"details",
 						g_variant_new ("(ss)", id, ""));
-	} else if (local_filename != NULL) {
+		return 0;
+	} else if (g_variant_dict_lookup (options, "local-filename", "^&ay", &local_filename)) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
 						"filename",
 						g_variant_new ("(s)", local_filename));
-	} else if (activate_ui) {
-		g_application_activate (app);
+		return 0;
 	}
 
-	*status = 0;
-
-out:
-	g_option_context_free (context);
-	return TRUE;
+	return -1;
 }
 
 static void
@@ -711,7 +695,9 @@ gs_application_class_init (GsApplicationClass *class)
 	G_OBJECT_CLASS (class)->dispose = gs_application_dispose;
 	G_APPLICATION_CLASS (class)->startup = gs_application_startup;
 	G_APPLICATION_CLASS (class)->activate = gs_application_activate;
-	G_APPLICATION_CLASS (class)->local_command_line = gs_application_local_command_line;
+	G_APPLICATION_CLASS (class)->handle_local_options = gs_application_handle_local_options;
+	G_APPLICATION_CLASS (class)->dbus_register = gs_application_dbus_register;
+	G_APPLICATION_CLASS (class)->dbus_unregister = gs_application_dbus_unregister;
 }
 
 GsApplication *
@@ -720,6 +706,7 @@ gs_application_new (void)
 	g_set_prgname("org.gnome.Software");
 	return g_object_new (GS_APPLICATION_TYPE,
 			     "application-id", "org.gnome.Software",
+			     "inactivity-timeout", 12000,
 			     NULL);
 }
 
