@@ -26,17 +26,16 @@
 
 #include "gs-app.h"
 #include "gs-app-row.h"
-#include "gs-cleanup.h"
 #include "gs-page.h"
 #include "gs-shell.h"
 #include "gs-utils.h"
 
-struct _GsPagePrivate
+typedef struct
 {
 	GsPluginLoader		*plugin_loader;
 	GCancellable		*cancellable;
 	GsShell			*shell;
-};
+} GsPagePrivate;
 
 G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GsPage, gs_page, GTK_TYPE_BIN)
 
@@ -65,7 +64,7 @@ gs_page_app_installed_cb (GObject *source,
 	GsPage *page = data->page;
 	GsPagePrivate *priv = gs_page_get_instance_private (page);
 	gboolean ret;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	ret = gs_plugin_loader_app_action_finish (plugin_loader,
 	                                          res,
@@ -103,7 +102,7 @@ gs_page_app_removed_cb (GObject *source,
 	GsPage *page = data->page;
 	GsPagePrivate *priv = gs_page_get_instance_private (page);
 	gboolean ret;
-	_cleanup_error_free_ GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	ret = gs_plugin_loader_app_action_finish (plugin_loader,
 	                                          res,
@@ -155,7 +154,7 @@ gs_page_remove_app (GsPage *page, GsApp *app)
 	GsPagePrivate *priv = gs_page_get_instance_private (page);
 	GtkResponseType response;
 	GtkWidget *dialog;
-	_cleanup_string_free_ GString *markup = NULL;
+	g_autoptr(GString) markup = NULL;
 
 	markup = g_string_new ("");
 	g_string_append_printf (markup,
