@@ -852,9 +852,8 @@ gs_shell_details_refresh_addons (GsShellDetails *self)
 		if (gs_app_get_state (addon) == AS_APP_STATE_UNAVAILABLE)
 			continue;
 
-		row = gs_app_addon_row_new ();
+		row = gs_app_addon_row_new (addon);
 
-		gs_app_addon_row_set_addon (GS_APP_ADDON_ROW (row), addon);
 		gtk_container_add (GTK_CONTAINER (self->list_box_addons), row);
 		gtk_widget_show (row);
 
@@ -911,11 +910,16 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 	g_autoptr(GError) error = NULL;
 	g_autofree gchar *tmp = NULL;
 
-	if (self->app != NULL)
-		g_object_unref (self->app);
-	self->app = gs_plugin_loader_filename_to_app_finish(plugin_loader,
-							    res,
-							    &error);
+	/* disconnect the old handlers */
+	if (self->app != NULL) {
+		g_signal_handlers_disconnect_by_func (self->app, gs_shell_details_notify_state_changed_cb, self);
+		g_signal_handlers_disconnect_by_func (self->app, gs_shell_details_progress_changed_cb, self);
+	}
+	/* save app */
+	g_set_object (&self->app,
+		      gs_plugin_loader_filename_to_app_finish(plugin_loader,
+							      res,
+							      &error));
 	if (self->app == NULL) {
 		GtkWidget *dialog;
 
@@ -938,7 +942,6 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 		return;
 	}
 
-	/* save app */
 	g_signal_connect_object (self->app, "notify::state",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 self, 0);
@@ -948,6 +951,9 @@ gs_shell_details_filename_to_app_cb (GObject *source,
 	g_signal_connect_object (self->app, "notify::licence",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 self, 0);
+	g_signal_connect_object (self->app, "notify::progress",
+				 G_CALLBACK (gs_shell_details_progress_changed_cb),
+				 self, 0);
 
 	/* print what we've got */
 	tmp = gs_app_to_string (self->app);
@@ -1015,13 +1021,20 @@ gs_shell_details_reload (GsShellDetails *self)
 void
 gs_shell_details_set_app (GsShellDetails *self, GsApp *app)
 {
+	g_return_if_fail (GS_IS_SHELL_DETAILS (self));
+	g_return_if_fail (GS_IS_APP (app));
+
 	/* get extra details about the app */
 	gs_shell_details_set_state (self, GS_SHELL_DETAILS_STATE_LOADING);
 
+	/* disconnect the old handlers */
+	if (self->app != NULL) {
+		g_signal_handlers_disconnect_by_func (self->app, gs_shell_details_notify_state_changed_cb, self);
+		g_signal_handlers_disconnect_by_func (self->app, gs_shell_details_progress_changed_cb, self);
+	}
 	/* save app */
-	if (self->app != NULL)
-		g_object_unref (self->app);
-	self->app = g_object_ref (app);
+	g_set_object (&self->app, app);
+
 	g_signal_connect_object (self->app, "notify::state",
 				 G_CALLBACK (gs_shell_details_notify_state_changed_cb),
 				 self, 0);
@@ -1271,10 +1284,14 @@ gs_shell_details_dispose (GObject *object)
 {
 	GsShellDetails *self = GS_SHELL_DETAILS (object);
 
+	if (self->app != NULL) {
+		g_signal_handlers_disconnect_by_func (self->app, gs_shell_details_notify_state_changed_cb, self);
+		g_signal_handlers_disconnect_by_func (self->app, gs_shell_details_progress_changed_cb, self);
+		g_clear_object (&self->app);
+	}
 	g_clear_object (&self->builder);
 	g_clear_object (&self->plugin_loader);
 	g_clear_object (&self->cancellable);
-	g_clear_object (&self->app);
 	g_clear_object (&self->session);
 
 	G_OBJECT_CLASS (gs_shell_details_parent_class)->dispose (object);
