@@ -46,9 +46,8 @@ gs_update_list_add_app (GsUpdateList *update_list,
 {
 	GtkWidget *app_row;
 
-	app_row = gs_app_row_new ();
+	app_row = gs_app_row_new (app);
 	gs_app_row_set_show_update (GS_APP_ROW (app_row), TRUE);
-	gs_app_row_set_app (GS_APP_ROW (app_row), app);
 	gtk_container_add (GTK_CONTAINER (update_list), app_row);
 	gs_app_row_set_size_groups (GS_APP_ROW (app_row),
 				    update_list->sizegroup_image,
