@@ -34,7 +34,6 @@ struct GsPluginPrivate {
 	GMutex			 store_mutex;
 	gchar			*locale;
 	gsize			 done_init;
-	gboolean		 has_hi_dpi_support;
 };
 
 static gboolean gs_plugin_refine_item (GsPlugin *plugin, GsApp *app, AsApp *item, GError **error);
@@ -93,9 +92,6 @@ gs_plugin_initialize (GsPlugin *plugin)
 	as_store_set_watch_flags (plugin->priv->store,
 				  AS_STORE_WATCH_FLAG_ADDED |
 				  AS_STORE_WATCH_FLAG_REMOVED);
-	g_signal_connect (plugin->priv->store, "changed",
-			  G_CALLBACK (gs_plugin_appstream_store_changed_cb),
-			  plugin);
 
 	/* AppInstall does not ever give us a long description */
 	if (gs_plugin_check_distro_id (plugin, "debian") ||
@@ -227,6 +223,11 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 		goto out;
 	}
 
+	/* watch for changes */
+	g_signal_connect (plugin->priv->store, "changed",
+			  G_CALLBACK (gs_plugin_appstream_store_changed_cb),
+			  plugin);
+
 	/* add search terms for apps not in the main source */
 	origins = gs_plugin_appstream_get_origins_hash (items);
 	for (i = 0; i < items->len; i++) {
@@ -241,15 +242,6 @@ gs_plugin_startup (GsPlugin *plugin, GError **error)
 			as_app_add_keyword (app, NULL, origin);
 		}
 	}
-
-	/* look for any application with a HiDPI icon kudo */
-	for (i = 0; i < items->len; i++) {
-		app = g_ptr_array_index (items, i);
-		if (as_app_has_kudo_kind (app, AS_KUDO_KIND_HI_DPI_ICON)) {
-			plugin->priv->has_hi_dpi_support = TRUE;
-			break;
-		}
-	}
 out:
 	g_mutex_unlock (&plugin->priv->store_mutex);
 	gs_profile_stop (plugin->profile, "appstream::startup");
@@ -496,6 +488,9 @@ gs_plugin_refine_item (GsPlugin *plugin,
 		case AS_APP_SOURCE_KIND_METAINFO:
 			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 			break;
+		case AS_APP_SOURCE_KIND_APPSTREAM:
+			gs_app_set_state (app, as_app_get_state (item));
+			break;
 		default:
 			break;
 		}
@@ -989,7 +984,8 @@ gs_plugin_add_installed (GsPlugin *plugin,
 	array = as_store_get_apps (plugin->priv->store);
 	for (i = 0; i < array->len; i++) {
 		item = g_ptr_array_index (array, i);
-		if (as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPDATA) {
+		if (as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPDATA ||
+		    as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_DESKTOP) {
 			g_autoptr(GsApp) app = NULL;
 			app = gs_app_new (as_app_get_id (item));
 			ret = gs_plugin_refine_item (plugin, app, item, error);
