@@ -51,7 +51,6 @@ gs_plugin_initialize (GsPlugin *plugin)
 	/* create private area */
 	plugin->priv = GS_PLUGIN_GET_PRIVATE (GsPluginPrivate);
 	plugin->priv->task = pk_task_new ();
-	pk_client_set_background (PK_CLIENT (plugin->priv->task), FALSE);
 	pk_client_set_interactive (PK_CLIENT (plugin->priv->task), FALSE);
 }
 
@@ -117,6 +116,9 @@ gs_plugin_refresh (GsPlugin *plugin,
 	if ((flags & GS_PLUGIN_REFRESH_FLAGS_UPDATES) == 0)
 		return TRUE;
 
+	/* cache age of 0 is user-initiated */
+	pk_client_set_background (PK_CLIENT (plugin->priv->task), cache_age > 0);
+
 	/* update UI as this might take some time */
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 
@@ -221,6 +223,60 @@ gs_plugin_packagekit_refresh_content_type_matches (const gchar *filename,
 	return TRUE;
 }
 
+/**
+ * gs_plugin_packagekit_refresh_guess_app_id:
+ */
+static gboolean
+gs_plugin_packagekit_refresh_guess_app_id (GsPlugin *plugin,
+					   GsApp *app,
+					   const gchar *filename,
+					   GCancellable *cancellable,
+					   GError **error)
+{
+	PkFiles *item;
+	guint i;
+	guint j;
+	gchar **fns;
+	g_auto(GStrv) files = NULL;
+	g_autoptr(PkResults) results = NULL;
+	g_autoptr(GPtrArray) array = NULL;
+
+	/* get file list so we can work out ID */
+	files = g_strsplit (filename, "\t", -1);
+	results = pk_client_get_files_local (PK_CLIENT (plugin->priv->task),
+					     files,
+					     cancellable,
+					     gs_plugin_packagekit_progress_cb, plugin,
+					     error);
+	if (results == NULL)
+		return FALSE;
+	array = pk_results_get_files_array (results);
+	if (array->len == 0) {
+		g_set_error (error,
+			     GS_PLUGIN_ERROR,
+			     GS_PLUGIN_ERROR_FAILED,
+			     "no files for %s", filename);
+		return FALSE;
+	}
+
+	/* find the first desktop file */
+	for (i = 0; i < array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		fns = pk_files_get_files (item);
+		for (j = 0; fns[j] != NULL; j++) {
+			if (g_str_has_suffix (fns[j], ".desktop")) {
+				g_autofree gchar *basename;
+				basename = g_path_get_basename (fns[j]);
+				gs_app_set_id (app, basename);
+				gs_app_set_kind (app, GS_APP_KIND_NORMAL);
+				gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
+				break;
+			}
+		}
+	}
+	return TRUE;
+}
+
 /**
  * gs_plugin_filename_to_app:
  */
@@ -234,7 +290,7 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
 	const gchar *package_id;
 	gboolean supported;
 	PkDetails *item;
-	PkResults *results = NULL;
+	g_autoptr (PkResults) results = NULL;
 	g_autofree gchar *basename = NULL;
 	g_auto(GStrv) files = NULL;
 	g_auto(GStrv) split = NULL;
@@ -303,6 +359,15 @@ gs_plugin_filename_to_app (GsPlugin *plugin,
 	gs_app_set_url (app, AS_URL_KIND_HOMEPAGE, pk_details_get_url (item));
 	gs_app_set_size (app, pk_details_get_size (item));
 	gs_app_set_licence (app, pk_details_get_license (item));
+
+	/* look for a desktop file so we can use a valid application id */
+	if (!gs_plugin_packagekit_refresh_guess_app_id (plugin,
+							app,
+							filename,
+							cancellable,
+							error))
+		return FALSE;
+
 	gs_plugin_add_app (list, app);
 	return TRUE;
 }
